<?php
/**
 * The template for displaying comments.
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package gossip
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="gossip-comment">

	<?php $comments_number = absint( get_comments_number() ); ?>

	<?php if ( have_comments() ) : ?>
		<h2 class="comments-title">
			<?php
			if ( ! have_comments() ) {
				esc_html_e( 'Leave a comment', 'gossip' );
			} elseif ( 1 === $comments_number ) {
				/* translators: %s: Post title. */
				printf( esc_html_x( 'One comment on &ldquo;%s&rdquo;', 'comments title', 'gossip' ), esc_html( get_the_title() ) );
			} else {
				printf(
				/* translators: 1: Number of comments, 2: Post title. */
					_nx( //phpcs:ignore
						'%1$s comment on &ldquo;%2$s&rdquo;',
						'%1$s comments on &ldquo;%2$s&rdquo;',
						$comments_number,
						'comments title',
						'gossip'
					),
					esc_html( number_format_i18n( $comments_number ) ),
					esc_html( get_the_title() )
				); // phpcs:ignore Standard.Category.SniffName.ErrorCode
			}
			?>
		</h2>

		<ol class="comment-list">
			<?php
				wp_list_comments(
					array(
						'style'       => 'ol',
						'short_ping'  => true,
						'avatar_size' => 120,
					)
				);
			?>
		</ol><!-- .comment-list -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through? ?>
		<nav id="comment-nav-below" class="navigation comment-navigation" role="navigation">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'gossip' ); ?></h2>
			<div class="nav-links">

				<div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments', 'gossip' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments', 'gossip' ) ); ?></div>

			</div><!-- .nav-links -->
		</nav><!-- #comment-nav-below -->
		<?php endif; // Check for comment navigation. ?>

	<?php endif; // Check for have_comments(). ?>

	<?php
		// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
		?>
		<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'gossip' ); ?></p>
	<?php endif; ?>
</div><!-- end .gossip-comments -->

<div class="gossip-comment-form">
	<?php comment_form(); ?>
</div><!-- end .gossip-comment-form -->
