<?php
/**
 * Theme Customizer
 *
 * @param string $wp_customize WordPress Customization API.
 */
function gossip_customizer_register( $wp_customize ) {
	/**
	 * Gossip Logo setting section
	 */
	$wp_customize->add_section(
		'gossip_logo_setting',
		array(
			'title'       => __( 'Gossip Logo', 'gossip' ),
			'description' => __( 'Gossip theme logo option settings', 'gossip' ),
			'priority'    => 30,
		)
	);

	// Setting & control for logo.
	$wp_customize->add_setting(
		'gossip_logo_toggle',
		array(
			'default'           => 2,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_logo_toggle',
			array(
				'label'    => __( 'Enable/Disable logo', 'gossip' ),
				'section'  => 'gossip_logo_setting',
				'settings' => 'gossip_logo_toggle',
				'type'     => 'select',
				'choices'  => array(
					1 => __( 'Enabled', 'gossip' ),
					2 => __( 'Disabled', 'gossip' ),
				),
			)
		)
	);

	// Setting & control for logo.
	$wp_customize->add_setting(
		'gossip_logo',
		array(
			'default'           => get_template_directory_uri() . '/assets/img/logo.png',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'gossip_logo',
			array(
				'label'    => __( 'Upload you logo', 'gossip' ),
				'section'  => 'gossip_logo_setting',
				'settings' => 'gossip_logo',
			)
		)
	);

	/**
	 * Gossip Header Search bar setting section
	 */
	$wp_customize->add_section(
		'gossip_search_setting',
		array(
			'title'       => __( 'Header Search Form', 'gossip' ),
			'description' => __( 'Gossip theme header search form Enable/Disable setting', 'gossip' ),
			'priority'    => 30,
		)
	);

	// Setting & control for Header Search bar.
	$wp_customize->add_setting(
		'gossip_search_toggle',
		array(
			'default'           => 1,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_search_toggle',
			array(
				'label'    => __( 'Enable/Disable Search Form', 'gossip' ),
				'section'  => 'gossip_search_setting',
				'settings' => 'gossip_search_toggle',
				'type'     => 'select',
				'choices'  => array(
					1 => __( 'Enabled', 'gossip' ),
					2 => __( 'Disabled', 'gossip' ),
				),
			)
		)
	);

	/**
	 * Gossip Social media icon settings
	 */
	$wp_customize->add_section(
		'gossip_social_media_icons',
		array(
			'title'       => __( 'Social Media', 'gossip' ),
			'description' => __( 'Social Media links', 'gossip' ),
			'priority'    => 30,
		)
	);

	// Setting & control facebook icon.
	$wp_customize->add_setting(
		'gossip_social_facebook',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_social_facebook',
			array(
				'label'    => __( 'Enter facebook link', 'gossip' ),
				'section'  => 'gossip_social_media_icons',
				'settings' => 'gossip_social_facebook',
			)
		)
	);

	// Setting & control twitter icon.
	$wp_customize->add_setting(
		'gossip_social_twitter',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_social_twitter',
			array(
				'label'    => __( 'Enter twitter link', 'gossip' ),
				'section'  => 'gossip_social_media_icons',
				'settings' => 'gossip_social_twitter',
			)
		)
	);

	// Setting & control youtube icon.
	$wp_customize->add_setting(
		'gossip_social_youtube',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_social_youtube',
			array(
				'label'    => __( 'Enter youtube link', 'gossip' ),
				'section'  => 'gossip_social_media_icons',
				'settings' => 'gossip_social_youtube',
			)
		)
	);

	// Setting & control google plus icon.
	$wp_customize->add_setting(
		'gossip_social_google_plus',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_social_google_plus',
			array(
				'label'    => __( 'Enter google plus link', 'gossip' ),
				'section'  => 'gossip_social_media_icons',
				'settings' => 'gossip_social_google_plus',
			)
		)
	);

	// Setting & control behance icon.
	$wp_customize->add_setting(
		'gossip_social_behance',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_social_behance',
			array(
				'label'    => __( 'Enter behance link', 'gossip' ),
				'section'  => 'gossip_social_media_icons',
				'settings' => 'gossip_social_behance',
			)
		)
	);

	// Setting & control linkedin icon.
	$wp_customize->add_setting(
		'gossip_social_linkedin',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_social_linkedin',
			array(
				'label'    => __( 'Enter linkedin link', 'gossip' ),
				'section'  => 'gossip_social_media_icons',
				'settings' => 'gossip_social_linkedin',
			)
		)
	);

	// Setting & control instagram icon.
	$wp_customize->add_setting(
		'gossip_social_instagram',
		array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_social_instagram',
			array(
				'label'    => __( 'Enter instagram link', 'gossip' ),
				'section'  => 'gossip_social_media_icons',
				'settings' => 'gossip_social_instagram',
			)
		)
	);

	/**
	 * Gossip Menu Section
	 */
	$wp_customize->add_section(
		'gossip_menu_setting',
		array(
			'title'       => __( 'Main Menu', 'gossip' ),
			'description' => __( 'Gossip theme Menu Settings', 'gossip' ),
			'priority'    => 30,
		)
	);

	// Setting & control for Header Menu position.
	$wp_customize->add_setting(
		'gossip_menu_toggle',
		array(
			'default'           => 1,
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_menu_toggle',
			array(
				'label'    => __( 'Change Menu Position', 'gossip' ),
				'section'  => 'gossip_menu_setting',
				'settings' => 'gossip_menu_toggle',
				'type'     => 'select',
				'choices'  => array(
					1 => __( 'Left', 'gossip' ),
					2 => __( 'Center', 'gossip' ),
					3 => __( 'Right', 'gossip' ),
				),
			)
		)
	);

	// Setting & control for Header Menu Background.
	$wp_customize->add_setting(
		'gossip_menu_background',
		array(
			'default'           => '#ffffff',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'gossip_menu_background',
			array(
				'label'      => __( 'Menu Background', 'gossip' ),
				'section'    => 'gossip_menu_setting',
				'settings'   => 'gossip_menu_background',
			) )
	);

	// Setting & control for Header Menu Background.
	$wp_customize->add_setting(
		'gossip_menu_color',
		array(
			'default'           => '#777778',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'gossip_menu_color',
			array(
				'label'      => __( 'Menu Color', 'gossip' ),
				'section'    => 'gossip_menu_setting',
				'settings'   => 'gossip_menu_color',
			) )
	);

	/**
	 * Gossip Footer text Sectoions
	 */
	$wp_customize->add_section(
		'gossip_footer_text_setting',
		array(
			'title'       => __( 'Footer Text', 'gossip' ),
			'description' => __( 'Footer Copyright text', 'gossip' ),
			'priority'    => 30,
		)
	);

	// Setting & control footer text.
	$wp_customize->add_setting(
		'gossip_footer_text',
		array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'gossip_footer_text',
			array(
				'label'    => __( 'Change footer copyright text', 'gossip' ),
				'section'  => 'gossip_footer_text_setting',
				'settings' => 'gossip_footer_text',
			)
		)
	);
}

add_action( 'customize_register', 'gossip_customizer_register' );